Documentation
¶
Index ¶
- Variables
- func SplitFile(fileSize int64) (chunks []oss.FileChunk, err error)
- func SplitFileByPartNum(fileSize int64, chunkNum int) ([]oss.FileChunk, error)
- func SplitFileByPartSize(fileSize int64, chunkSize int64) ([]oss.FileChunk, error)
- func UploadDigestRange(stream model.FileStreamer, rangeSpec string) (result string, err error)
- type Addition
- type FileObj
- type Pan115
- func (d *Pan115) Config() driver.Config
- func (d *Pan115) Copy(ctx context.Context, srcObj, dstDir model.Obj) error
- func (c *Pan115) DownloadWithUA(pickCode, ua string) (*driver115.DownloadInfo, error)
- func (d *Pan115) Drop(ctx context.Context) error
- func (d *Pan115) GetAddition() driver.Additional
- func (d *Pan115) Init(ctx context.Context) error
- func (d *Pan115) Link(ctx context.Context, file model.Obj, args model.LinkArgs) (*model.Link, error)
- func (d *Pan115) List(ctx context.Context, dir model.Obj, args model.ListArgs) ([]model.Obj, error)
- func (d *Pan115) MakeDir(ctx context.Context, parentDir model.Obj, dirName string) error
- func (d *Pan115) Move(ctx context.Context, srcObj, dstDir model.Obj) error
- func (d *Pan115) Put(ctx context.Context, dstDir model.Obj, stream model.FileStreamer, ...) error
- func (d *Pan115) Remove(ctx context.Context, obj model.Obj) error
- func (d *Pan115) Rename(ctx context.Context, srcObj model.Obj, newName string) error
- func (d *Pan115) UploadByMultipart(params *driver115.UploadOSSParams, fileSize int64, stream model.FileStreamer, ...) error
- func (d *Pan115) WaitLimit(ctx context.Context) error
Constants ¶
This section is empty.
Variables ¶
var UserAgent = driver115.UA115Desktop
Functions ¶
func SplitFileByPartNum ¶
SplitFileByPartNum splits big file into parts by the num of parts. Split the file with specified parts count, returns the split result when error is nil.
func SplitFileByPartSize ¶
SplitFileByPartSize splits big file into parts by the size of parts. Splits the file by the part size. Returns the FileChunk when error is nil.
func UploadDigestRange ¶
func UploadDigestRange(stream model.FileStreamer, rangeSpec string) (result string, err error)
Types ¶
type Addition ¶
type Addition struct {
Cookie string `json:"cookie" type:"text" help:"one of QR code token and cookie required"`
QRCodeToken string `json:"qrcode_token" type:"text" help:"one of QR code token and cookie required"`
QRCodeSource string `` /* 145-byte string literal not displayed */
PageSize int64 `json:"page_size" type:"number" default:"56" help:"list api per page size of 115 driver"`
LimitRate float64 `json:"limit_rate" type:"number" default:"2" help:"limit all api request rate (1r/[limit_rate]s)"`
driver.RootID
}
type FileObj ¶
func (*FileObj) CreateTime ¶
type Pan115 ¶
func (*Pan115) DownloadWithUA ¶
func (c *Pan115) DownloadWithUA(pickCode, ua string) (*driver115.DownloadInfo, error)
func (*Pan115) GetAddition ¶
func (d *Pan115) GetAddition() driver.Additional
func (*Pan115) Put ¶
func (d *Pan115) Put(ctx context.Context, dstDir model.Obj, stream model.FileStreamer, up driver.UpdateProgress) error
func (*Pan115) UploadByMultipart ¶
func (d *Pan115) UploadByMultipart(params *driver115.UploadOSSParams, fileSize int64, stream model.FileStreamer, dirID string, opts ...driver115.UploadMultipartOption) error
UploadByMultipart upload by mutipart blocks
Click to show internal directories.
Click to hide internal directories.